@@ -1,16 +1,9 @@
 from json import dumps, loads
 from kafka import KafkaProducer
-from enum import Enum
 from kafka import KafkaConsumer
 from kafka.errors import KafkaError
 
 
-class Action(Enum):
-    Added = 1
-    Modified = 2
-    Deleted = 3
-
-
 def produce(broker_names, topic, data_item):
     producer = KafkaProducer(bootstrap_servers=broker_names,
                              value_serializer=lambda x:
@@ -23,6 +16,17 @@ def produce(broker_names, topic, data_item):
         raise
 
 
+def produce_with_key(broker_names, topic, data_item, key):
+    producer = KafkaProducer(bootstrap_servers=broker_names,
+                             value_serializer=lambda x:
+                             dumps(x).encode('utf-8')
+                             )
+    future = producer.send(topic, value=data_item, key=key)
+    try:
+        record_metadata = future.get(timeout=10)
+    except KafkaError:
+        raise
+
 
 def consume(broker_names, topic, consumer_group, auto_offset_reset, consumer_timeout_ms):
     consumer = KafkaConsumer(
@@ -34,10 +38,8 @@ def consume(broker_names, topic, consumer_group, auto_offset_reset, consumer_tim
         group_id=consumer_group,
         value_deserializer=lambda x: loads(x.decode('utf-8')),
         consumer_timeout_ms=consumer_timeout_ms
-        )
+    )
     items = []
     for msg in consumer:
         items.append(msg.value)
     return items
-
-
